=======
History
=======

0.1.1-alpha (2020-09-15 16:30)
------------------------------

cli.bars
^^^^^^^^

- Minimally functional: ``$ csvviz bars -x name -y things examples/tings.csv``



0.1.0-alpha (2020-09-15)
------------------------

First release on PyPI. Just a cookiecutter-pypackage skeleton stub.


